==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/uml2sd/ztest/testLoaders.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.ztest;

import java.net.URL;
import java.util.ArrayList;

import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFindProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDPagingProvider;
import org.eclipse.hyades.uml2sd.ui.actions.widgets.Criteria;
import org.eclipse.hyades.uml2sd.ui.core.AsyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.core.ExecutionOccurrence;
import org.eclipse.hyades.uml2sd.ui.core.Frame;
import org.eclipse.hyades.uml2sd.ui.core.Lifeline;
import org.eclipse.hyades.uml2sd.ui.core.LifelineCategories;
import org.eclipse.hyades.uml2sd.ui.core.Stop;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessage;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.drawings.impl.ImageImpl;
import org.eclipse.hyades.uml2sd.ui.view.SDView;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;

/**
 * @author sveyrier
 *
 */
public class testLoaders implements ISDFindProvider,ISDFilterProvider,ISDPagingProvider{

	public SDView v;
	
	public int page =1;

	public testLoaders()
	{
	}
	
	public void setViewer(SDView  j)
	{
		v = j;
		final Frame testFrame = new Frame();
		testFrame.setName("Sequence Diagram"); //$NON-NLS-1$
		LifelineCategories[] tt;
		tt=new LifelineCategories[2];
		tt[0]=new LifelineCategories();
		tt[1]=new LifelineCategories();
		tt[1].setName("Categorie 1"); //$NON-NLS-1$
		tt[0].setImage(new ImageImpl("copy_r_co.gif")); //$NON-NLS-1$
		tt[1].setImage(new ImageImpl("big.gif2")); //$NON-NLS-1$
		tt[0].setName("Categorie 0"); //$NON-NLS-1$
		testFrame.setLifelineCategories(tt);
		Lifeline lifeline=new Lifeline();
		lifeline.setName("LifeLine " + 0); //$NON-NLS-1$
		testFrame.addLifeLine(lifeline);
		SyncMessage mn = new SyncMessage();
		lifeline.getNewEventOccurrence();
		mn.setStartLifeline(lifeline);
		mn.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(mn);
		SyncMessage mn2 = new SyncMessage();
		lifeline.getNewEventOccurrence();
		lifeline.setCategory(0);
		mn2.setEndLifeline(lifeline);
		testFrame.setTimeUnitName("Toto"); //$NON-NLS-1$
		mn2.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(mn2);
		testFrame.forceEventOccurrenceSpacing(15);
		for (int i=1;i<500;i++)
		{
			lifeline=new Lifeline();
			lifeline.setName("LifeLine " + i); //$NON-NLS-1$
			lifeline.setCategory(1);
			testFrame.addLifeLine(lifeline);

			SyncMessage m3= new SyncMessage();
			testFrame.getLifeline(i-1).getNewEventOccurrence();
			m3.setStartLifeline(testFrame.getLifeline(i-1));
			m3.setEndLifeline(testFrame.getLifeline(i));
			m3.setName("Message "+i); //$NON-NLS-1$
			testFrame.addMessage(m3);
			if (i==11)
			m3.setTime(i-400);///34.8);
			else if (i==6)
				m3.setTime(i);
			else m3.setTime(i+1);
		
		}
//		int f = 50000;
int f=0;
		for (int i=testFrame.lifeLinesCount()-1; i > 0; i--)
		{
			SyncMessageReturn m = new SyncMessageReturn();
			testFrame.getLifeline(i).getNewEventOccurrence();
			m.setStartLifeline(testFrame.getLifeline(i));
			m.setEndLifeline(testFrame.getLifeline(i-1));
			testFrame.addMessage(m);
			m.setName("Message return "+i); //$NON-NLS-1$
//			m.setTime(i+f);
			if (i+1<testFrame.lifeLinesCount())
			{
				SyncMessage h=testFrame.getSyncMessage(i+1);
				m.setMessage(h);
			}
		}
	
		SyncMessage m1 =testFrame.getSyncMessage(100);
		SyncMessage m2 =testFrame.getSyncMessage(4);
//		testFrame.getMessage().set(100,m2);
//		testFrame.getMessages().set(4,m1);
	
		for (int i=0;i<testFrame.lifeLinesCount();i++)
		{
			if (i>0)
			{
				ExecutionOccurrence occ= new ExecutionOccurrence();
				occ.setStartOccurrence(testFrame.getSyncMessage(i).getEventOccurrence()+1);
				occ.setEndOccurrence(testFrame.getSyncMessageReturn(testFrame.syncMessageReturnCount()-i).getEventOccurrence());
				testFrame.getLifeline(i).addExecution(occ);
				occ.setName("*******************TEST ****************"); //$NON-NLS-1$
//				if (i==4)
//				occ.setColor(50,50,50);
			}
		}
	
		Stop s = new Stop();
		s.setEventOccurrence(testFrame.getLifeline(1).getNewEventOccurrence());
		testFrame.getLifeline(1).setStop(s);
	
		AsyncMessageReturn m = new AsyncMessageReturn();
		m.setStartLifeline(testFrame.getLifeline(1));
		m.setEndLifeline(testFrame.getLifeline(3));
		m.setStartOccurrence(6);
		m.setEndOccurrence(2);
		m.setStartTime(20);
		m.setEndTime(40);
		m.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(m);
	
/*		SyncMessageReturn ma = new SyncMessageReturn();
		testFrame.getLifeline(2).getNewEventOccurrence();
		ma.setStartLifeline(testFrame.getLifeline(2));
		testFrame.getLifeline(2).getNewEventOccurrence();
		ma.setEndLifeline(testFrame.getLifeline(2));
		ma.setName("toto23frefrefrfrefrfe");
		testFrame.addMessage(ma);*/
		v.setFrame(testFrame);
	}

	public boolean hasNextPage() 
	{	
		if (page==1)
			return true;
		else return false;
	}

	public boolean hasPrevPage() 
	{
		if (page==2)
			return true;
		else return false;
	}
	
	public void prevPage()
	{
		page=1;
		setViewer(v);
	}

	public void nextPage()
	{
		page =2;
		final Frame testFrame = new Frame();
		testFrame.setName("Sequence Diagram"); //$NON-NLS-1$
		
		Lifeline lifeline=new Lifeline();
		lifeline.setName("LifeLine " + 0); //$NON-NLS-1$
		testFrame.addLifeLine(lifeline);
		lifeline=new Lifeline(); 
		lifeline.setName("LifeLine " + 1); //$NON-NLS-1$
		testFrame.addLifeLine(lifeline);
/*		lifeline=new Lifeline();
				lifeline.setName("LifeLine " + 1);
				testFrame.addLifeLine(lifeline);
		lifeline=new Lifeline();
				lifeline.setName("LifeLine " + 1);
				testFrame.addLifeLine(lifeline);*/
		int count=-1;
		for (int i=1;i<30;i++)
		{

			SyncMessage m3 = new SyncMessage();
			m3.autoSetStartLifeline(testFrame.getLifeline(0));
			m3.autoSetEndLifeline(testFrame.getLifeline(0));
			m3.setName("Message "+i); //$NON-NLS-1$
			testFrame.addMessage(m3);
//			m3.setTime(i+1);
		
			SyncMessageReturn m = new SyncMessageReturn();
			m.autoSetStartLifeline(testFrame.getLifeline(0));
			m.autoSetEndLifeline(testFrame.getLifeline(0));
			testFrame.addMessage(m);
//			m.setTime(i+1);
			m.setName("Message return "+i); //$NON-NLS-1$
			
			Stop s = new Stop();
			s.setEventOccurrence(testFrame.getLifeline(0).getNewEventOccurrence());
			testFrame.getLifeline(0).setStop(s);
			
			ExecutionOccurrence occ= new ExecutionOccurrence();
			occ.setStartOccurrence(testFrame.getSyncMessage(i-1).getEventOccurrence());
			occ.setEndOccurrence(testFrame.getSyncMessageReturn(i-1).getEventOccurrence());
			testFrame.getLifeline(0).addExecution(occ);
/*			lifeline=new Lifeline(); 
			Lifeline h=testFrame.getLifeline(i);
			lifeline.setCurrentEventOccurrence(h.getEventOccurrence());
			lifeline.setName("LifeLine " + i+"\n"+"DGGDDDD");
			testFrame.addLifeLine(lifeline);
			ExecutionOccurrence occ= new ExecutionOccurrence();
			occ.setStartOccurrence(lifeline.getNewEventOccurrence());
			occ.setEndOccurrence(lifeline.getNewEventOccurrence());
			lifeline.addExecution(occ);*/
		}
		
		
		v.setFrame(testFrame);
	}
	
	public boolean find (Criteria toSearch)
	{
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.ui.actions.ISDProvider#getType()
	 */
	public LifelineCategories[] getCategories() {
		LifelineCategories[] t = new LifelineCategories[1];
	 	t[0]=new LifelineCategories();
	 	t[0].setName("Tab2"); //$NON-NLS-1$
//		t[1]=new LifelineCategories();
//		t[1].setName("Tab2");
	 	return t;
	}

	public boolean isLifelineSupported() {
		return false;
	}

	public boolean isSyncMessageSupported() {
		return false;
	}

	public boolean isSyncMessageReturnSupported() {
		return false;
	}

	public boolean isAsyncMessageSupported() {
		return false;
	}

	public boolean isAsyncMessageReturnSupported() {
		return false;
	}

	public boolean isStopSupported() {
		return false;
	}
	
	private static URL BASIC_URL=null;
	static
	{
		//URL to get images from plugins
		//perhaps we can found better code to load images ...
		//but at this time I know this: 
		try {
		BASIC_URL = new URL( "platform", "localhost", "plugin");//$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
		} catch( Exception E ) {
			System.err.println(E);
		}
	}
	   
	public Image getResourceImage( String _name )
	{
		try {
		 URL url=new URL( BASIC_URL, "plugin/org.eclipse.hyades.uml2sd.ui/icons/"+ _name);//$NON-NLS-1$
		 ImageDescriptor img = ImageDescriptor.createFromURL( url );
		return img.createImage() ;
		} catch( Exception E ) {
					 System.err.println(E);
				 }
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.IExtendedFindProvider#getFindAction()
	 */
	public Action getFindAction() {
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider#filter(java.util.ArrayList)
	 */
	public boolean filter(ArrayList filters) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider#getCurrentFilters()
	 */
	public ArrayList getCurrentFilters() {
		// TODO Auto-generated method stub
		return null;
	}

}

==> hyades.source_3.2.0_20041221_1637.zip: org/eclipse/hyades/uml2sd/ztest/testLoaders.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.ztest;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFindProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDPagingProvider;
import org.eclipse.hyades.uml2sd.ui.actions.widgets.Criteria;
import org.eclipse.hyades.uml2sd.ui.core.AsyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.core.ExecutionOccurrence;
import org.eclipse.hyades.uml2sd.ui.core.Frame;
import org.eclipse.hyades.uml2sd.ui.core.Lifeline;
import org.eclipse.hyades.uml2sd.ui.core.LifelineCategories;
import org.eclipse.hyades.uml2sd.ui.core.Stop;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessage;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.core.internal.EllipsisisMessage;
import org.eclipse.hyades.uml2sd.ui.drawings.impl.ImageImpl;
import org.eclipse.hyades.uml2sd.ui.load.IUml2SDLoader;
import org.eclipse.hyades.uml2sd.ui.view.SDView;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;

/**
 * @author sveyrier
 *
 */
public class testLoaders implements IUml2SDLoader,ISDFindProvider,ISDFilterProvider,ISDPagingProvider{

	public SDView v;
	
	public int page =1;

	public testLoaders()
	{
	}
	
	public void setViewer(SDView  j)
	{
		v = j;
		final Frame testFrame = new Frame();
		testFrame.setName("Sequence Diagram"); //$NON-NLS-1$
		LifelineCategories[] tt;
		tt=new LifelineCategories[2];
		tt[0]=new LifelineCategories();
		tt[1]=new LifelineCategories();
		tt[1].setName("Categorie 1"); //$NON-NLS-1$
		tt[0].setImage(new ImageImpl("copy_r_co.gif")); //$NON-NLS-1$
		tt[1].setImage(new ImageImpl("big.gif2")); //$NON-NLS-1$
		tt[0].setName("Categorie 0"); //$NON-NLS-1$
		testFrame.setLifelineCategories(tt);
		Lifeline lifeline=new Lifeline();
		lifeline.setName("LifeLine " + 0); //$NON-NLS-1$
		testFrame.addLifeLine(lifeline);
//		SyncMessage mn = new SyncMessage();
		EllipsisisMessage mn = new EllipsisisMessage();
		lifeline.getNewEventOccurrence();
		mn.setStartLifeline(lifeline);
		mn.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(mn);
		
		SyncMessage mn3 = new SyncMessage();
		mn3.setStartLifeline(lifeline);
//		mn.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(mn3);
		
		SyncMessage mn2 = new SyncMessage();
		lifeline.getNewEventOccurrence();
		lifeline.setCategory(0);
		mn2.setEndLifeline(lifeline);
		testFrame.setTimeUnitName("Toto"); //$NON-NLS-1$
		mn2.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(mn2);
//		testFrame.forceEventOccurrenceSpacing(15);
		for (int i=1;i<10;i++)
		{
			lifeline=new Lifeline();
			lifeline.setName("LifeLine " + i); //$NON-NLS-1$
			lifeline.setCategory(1);
			testFrame.addLifeLine(lifeline);

			SyncMessage m3= new SyncMessage();
			testFrame.getLifeline(i-1).getNewEventOccurrence();
			m3.setStartLifeline(testFrame.getLifeline(i-1));
			m3.setEndLifeline(testFrame.getLifeline(i));
			m3.setName("Message "+i); //$NON-NLS-1$
			testFrame.addMessage(m3);
			if (i==11)
			m3.setTime(i-400);///34.8);
			else if (i==6)
				m3.setTime(i);
			else m3.setTime(i+1);
		
		}
//		int f = 50000;
int f=0;
		for (int i=testFrame.lifeLinesCount()-1; i > 0; i--)
		{
			SyncMessageReturn m = new SyncMessageReturn();
			testFrame.getLifeline(i).getNewEventOccurrence();
			m.setStartLifeline(testFrame.getLifeline(i));
			m.setEndLifeline(testFrame.getLifeline(i-1));
			testFrame.addMessage(m);
			m.setName("Message return "+i); //$NON-NLS-1$
//			m.setTime(i+f);
			if (i+1<testFrame.lifeLinesCount())
			{
				SyncMessage h=testFrame.getSyncMessage(i+1);
				m.setMessage(h);
			}
		}
	
		SyncMessage m1 =testFrame.getSyncMessage(100);
		SyncMessage m2 =testFrame.getSyncMessage(4);
//		testFrame.getMessage().set(100,m2);
//		testFrame.getMessages().set(4,m1);
	
		for (int i=0;i<testFrame.lifeLinesCount();i++)
		{
			if (i>0)
			{
				ExecutionOccurrence occ= new ExecutionOccurrence();
				occ.setStartOccurrence(testFrame.getSyncMessage(i).getEventOccurrence()+1);
				occ.setEndOccurrence(testFrame.getSyncMessageReturn(testFrame.syncMessageReturnCount()-i).getEventOccurrence());
				testFrame.getLifeline(i).addExecution(occ);
				occ.setName("*******************TEST ****************"); //$NON-NLS-1$
//				if (i==4)
//				occ.setColor(50,50,50);
			}
		}
	
		Stop s = new Stop();
		s.setEventOccurrence(testFrame.getLifeline(1).getNewEventOccurrence());
		testFrame.getLifeline(1).setStop(s);
	
		AsyncMessageReturn m = new AsyncMessageReturn();
		m.setStartLifeline(testFrame.getLifeline(1));
		m.setEndLifeline(testFrame.getLifeline(3));
		m.setStartOccurrence(6);
		m.setEndOccurrence(2);
		m.setStartTime(20);
		m.setEndTime(40);
		m.setName("*******************TEST ****************"); //$NON-NLS-1$
		testFrame.addMessage(m);
	
/*		SyncMessageReturn ma = new SyncMessageReturn();
		testFrame.getLifeline(2).getNewEventOccurrence();
		ma.setStartLifeline(testFrame.getLifeline(2));
		testFrame.getLifeline(2).getNewEventOccurrence();
		ma.setEndLifeline(testFrame.getLifeline(2));
		ma.setName("toto23frefrefrfrefrfe");
		testFrame.addMessage(ma);*/
		v.setFrame(testFrame);
		v.getSDWidget().setReorderMode(true);
	}

	public boolean hasNextPage() 
	{	
		if (page==1)
			return true;
		else return false;
	}

	public boolean hasPrevPage() 
	{
		if (page==2)
			return true;
		else return false;
	}
	
	public void prevPage()
	{
		page=1;
		setViewer(v);
	}

	public void nextPage()
	{
		page =2;
		final Frame testFrame = new Frame();
		testFrame.setName("Sequence Diagram"); //$NON-NLS-1$
		
		Lifeline lifeline=new Lifeline();
		lifeline.setName("LifeLine " + 0); //$NON-NLS-1$
		testFrame.addLifeLine(lifeline);
		lifeline=new Lifeline(); 
		lifeline.setName("LifeLine " + 1); //$NON-NLS-1$
		testFrame.addLifeLine(lifeline);
/*		lifeline=new Lifeline();
				lifeline.setName("LifeLine " + 1);
				testFrame.addLifeLine(lifeline);
		lifeline=new Lifeline();
				lifeline.setName("LifeLine " + 1);
				testFrame.addLifeLine(lifeline);*/
		int count=-1;
		for (int i=1;i<30;i++)
		{

			SyncMessage m3 = new SyncMessage();
			m3.autoSetStartLifeline(testFrame.getLifeline(0));
			m3.autoSetEndLifeline(testFrame.getLifeline(0));
			m3.setName("Message "+i); //$NON-NLS-1$
			testFrame.addMessage(m3);
//			m3.setTime(i+1);
		
			SyncMessageReturn m = new SyncMessageReturn();
			m.autoSetStartLifeline(testFrame.getLifeline(0));
			m.autoSetEndLifeline(testFrame.getLifeline(0));
			testFrame.addMessage(m);
//			m.setTime(i+1);
			m.setName("Message return "+i); //$NON-NLS-1$
			
			Stop s = new Stop();
			s.setEventOccurrence(testFrame.getLifeline(0).getNewEventOccurrence());
			testFrame.getLifeline(0).setStop(s);
			
			ExecutionOccurrence occ= new ExecutionOccurrence();
			occ.setStartOccurrence(testFrame.getSyncMessage(i-1).getEventOccurrence());
			occ.setEndOccurrence(testFrame.getSyncMessageReturn(i-1).getEventOccurrence());
			testFrame.getLifeline(0).addExecution(occ);
/*			lifeline=new Lifeline(); 
			Lifeline h=testFrame.getLifeline(i);
			lifeline.setCurrentEventOccurrence(h.getEventOccurrence());
			lifeline.setName("LifeLine " + i+"\n"+"DGGDDDD");
			testFrame.addLifeLine(lifeline);
			ExecutionOccurrence occ= new ExecutionOccurrence();
			occ.setStartOccurrence(lifeline.getNewEventOccurrence());
			occ.setEndOccurrence(lifeline.getNewEventOccurrence());
			lifeline.addExecution(occ);*/
		}
		
		
		v.setFrame(testFrame);
	}
	
	public boolean find (Criteria toSearch)
	{
		return false;
	}
	
	/**
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFindProvider#cancel()
	 */
	public void cancel() {
		// Nothing to do
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.ui.actions.ISDProvider#getType()
	 */
	public LifelineCategories[] getCategories() {
		LifelineCategories[] t = new LifelineCategories[1];
	 	t[0]=new LifelineCategories();
	 	t[0].setName("Tab2"); //$NON-NLS-1$
//		t[1]=new LifelineCategories();
//		t[1].setName("Tab2");
	 	return t;
	}

	public boolean isLifelineSupported() {
		return false;
	}

	public boolean isSyncMessageSupported() {
		return false;
	}

	public boolean isSyncMessageReturnSupported() {
		return false;
	}

	public boolean isAsyncMessageSupported() {
		return false;
	}

	public boolean isAsyncMessageReturnSupported() {
		return false;
	}

	public boolean isStopSupported() {
		return false;
	}
	
	private static URL BASIC_URL=null;
	static
	{
		//URL to get images from plugins
		//perhaps we can found better code to load images ...
		//but at this time I know this: 
		try {
		BASIC_URL = new URL( "platform", "localhost", "plugin");//$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
		} catch( Exception E ) {
			System.err.println(E);
		}
	}
	   
	public Image getResourceImage( String _name )
	{
		try {
		 URL url=new URL( BASIC_URL, "plugin/org.eclipse.hyades.uml2sd.ui/icons/"+ _name);//$NON-NLS-1$
		 ImageDescriptor img = ImageDescriptor.createFromURL( url );
		return img.createImage() ;
		} catch( Exception E ) {
					 System.err.println(E);
				 }
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.IExtendedFindProvider#getFindAction()
	 */
	public Action getFindAction() {
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider#filter(java.util.ArrayList)
	 */
	public boolean filter(List filters) {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider#getCurrentFilters()
	 */
	public ArrayList getCurrentFilters() {
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.load.IUml2SDLoader#getTitleString()
	 */
	public String getTitleString() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.uml2sd.ui.load.IUml2SDLoader#aboutToBeReplaced()
	 */
	public void aboutToBeReplaced() {
		// TODO Auto-generated method stub
		
	}

}
